#
# spec file for package python-translation-finder
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2019-2021 Matthias Fehring <buschmann23@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname translation-finder
Name:           python-translation-finder
Version:        2.19
Release:        1.3
Summary:        Translation Files Finder
License:        GPL-3.0-or-later
URL:            https://github.com/WeblateOrg/translation-finder
# test_data/linked has to be symlink, hance using github tar ball
Source:         https://github.com/WeblateOrg/translation-finder/archive/%{version}.tar.gz#/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module charset-normalizer}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module ruamel.yaml}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module twine}
BuildRequires:  %{python_module weblate-language-data >= 2021.2}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-charset-normalizer
Requires:       python-ruamel.yaml
Requires:       python-weblate-language-data >= 2021.2
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
A translation file finder for Weblate, translation tool with tight version control integration.

%prep
%setup -q -n %{modname}-%{version}
sed -i -e '/pytest-runner/d' setup.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/weblate-discover
%python_expand %fdupes %{buildroot}%{$python_sitelib}
# remove test data
%python_expand rm -r %{buildroot}%{$python_sitelib}/translation_finder/test_data

%post
%python_install_alternative weblate-discover

%postun
%python_uninstall_alternative weblate-discover

%check
%pytest

%files %{python_files}
%doc CHANGES.rst README.rst
%license LICENSE
%python_alternative %{_bindir}/weblate-discover
%{python_sitelib}/translation_finder
%{python_sitelib}/translation_finder-%{version}*info

%changelog
* Wed Nov 20 2024 Dirk Müller <dmueller@suse.com>
- update to 2.19:
  * Fixed crasn on corrupt YAML files.
* Thu Nov 14 2024 Markéta Machová <mmachova@suse.com>
- update to 2.18
  * Added support for Format.JS files.
  * Offer bilingual configuration for CSV.
  * Fixed crash on corrupted Transifex configuration.
  * Improved app store metadata detection.
  * Improved template detection for text files.
  * Improved detection of iOS translation files.
  * Added type annotations.
* Fri Dec 29 2023 Dirk Müller <dmueller@suse.com>
- update to 2.16:
  * Fixed detection UTF-16 Strings files.
  * Fixed detection of files with some special chars.
  * Added support for Mobile Kotlin resources.
* Tue Mar 21 2023 Dirk Müller <dmueller@suse.com>
- update to 2.15:
  * Added support for gotext JSON.
  * Added support for i18next JSON v4.
  * REUSE 3.0 compliance.
* Tue Oct 11 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2.14
  * Released on 11th August 2022.
  * Added detection of XLIFF format variants.
  * Added support for TXT format.
  * Added support for adding hint via API.
* Tue Mar 16 2021 Matthias Fehring <buschmann23@opensuse.org>
- Update to 2.9
  * Fixed discovery execution in standalone environments.
- Update to 2.8
  * Added detection of RC files.
  * Added detection of TBX files.
- Update to 2.7
  * Fixed support for CSV files.
  * Added eager detection mode.
  * Added type hints.
- Update to 2.6
  * Added support for CSV files.
  * Improved detection of PHP files.
  * Removed filtering of test files.
  * Finder now skips non accessible directories.
* Thu Feb 11 2021 Matthias Fehring <buschmann23@opensuse.org>
- Update to 2.5:
  * Improved POT detection in some cases.
  * Tested with Python 3.9.
- Update to 2.4:
  * Fixed build of wheel packages.
- Update to 2.3:
  * New dependency on weblate-language-data module.
  * Reduced amount of false positives on language codes inside a filename.
  * Improved iOS strings encoding detection.
  * Removed charamel dependency.
- Update to 2.2:
  * Added detection of Golang i18n json files.
  * Added detection of TOML files.
  * Improved charset detection by switching to charamel.
  * Dropped support for Python 3.5.
  * Added detection of ARB files.
* Tue Jun 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.1:
  * Added discovery support for formats newly supported by Weblate (HTML, IDML, OpenDocument, InnoSetup and INI).
* Wed Apr 15 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.0:
  * Dropped support for Python 2.
  * Improved i18next detection.
  * Improved detection of monolingual templates.
* Wed Mar 11 2020 pgajdos@suse.com
- version update to 1.8
  * Fixed discovery of filenames with digits.
  * Fixed crash on invalid YAML files.
* Fri Nov  8 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.7 bsc#1142582:
  * Improved handling of invalid JSON files.
  * Improved detection of flat JSON files.
  * Improved compatibility with OSX.
  * Improved detection of new base with gettext PO files.
* Mon Jul 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.6 bsc#1142582:
  * Improved discovery of POT files.
  * Added support for subtitle files supported in Weblate 3.7.
  * Improved detection of actual JSON formats.
  * Added support for detecting PHP files.
  * Improved detection of YAML formats.
* Mon Jun  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.5:
  * Various performance improvements.
  * Added detection of Fluent translations.
  * Improved detection of language code within filename.
  * Added detection of YAML translations.
* Mon May  6 2019 pgajdos@suse.com
- version update to 1.4
  * Improved detection in Perl code.
  * Extended skip list for language codes.
  * Improved detection of nested language codes with country suffix.
  * Improved processing of Transifex .tx/config files.
  * Include discovery metadata in API results.
  * Improve detection of files in source directory.
  * Fixed discovery of monolingual files in root.
  * Improved detection of non language paths.
* Wed Apr  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not use %%pytest macro for now to get this in Leap faster
* Tue Apr  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.1:
  * Improved detection of translation with full language code.
  * Improved detection of language code in directory and file name.
  * Improved detection of language code separated by full stop.
  * Added detection for app store metadata files.
  * Added detection for JSON files.
  * Ignore symlinks during discovery.
  * Improved detection of matching pot files in several corner cases.
  * Improved detection of monolingual Gettext.
- Fix the deps to not pull coverage things
* Wed Mar 20 2019 Matthias Fehring <buschmann23@opensuse.org>
- initial package version 1.0
